==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPositionSettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSizeDescriptionMetadata } from "./WebSizeDescriptionMetadata";
import { WebPositionSettingsDescription } from "./WebPositionSettingsDescription";
/**
 * @hidden
 */
export let WebPositionSettingsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPositionSettingsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPositionSettingsDescriptionMetadata.a == null) {
                WebPositionSettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPositionSettingsDescriptionMetadata.c(WebPositionSettingsDescriptionMetadata.a);
            }
            if (a.k(WebPositionSettingsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPositionSettingsDescriptionMetadata.a);
            WebSizeDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PositionSettings");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Target", "Unknown");
            a.item("HorizontalDirection", "ExportedType:string:GridHorizontalAlignment");
            a.item("HorizontalDirection@names", "Left;Center;Right");
            a.item("VerticalDirection", "ExportedType:string:GridVerticalAlignment");
            a.item("VerticalDirection@names", "Top;Middle;Bottom");
            a.item("HorizontalStartPoint", "ExportedType:string:GridHorizontalAlignment");
            a.item("HorizontalStartPoint@names", "Left;Center;Right");
            a.item("VerticalStartPoint", "ExportedType:string:GridVerticalAlignment");
            a.item("VerticalStartPoint@names", "Top;Middle;Bottom");
            a.item("MinSize", "ExportedType:WebSize");
        }
        static d(a) {
            WebPositionSettingsDescriptionMetadata.b(a);
            a.ad("WebPositionSettings", () => new WebPositionSettingsDescription());
            a.ac("WebPositionSettings", WebPositionSettingsDescriptionMetadata.a);
        }
    }
    WebPositionSettingsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPositionSettingsDescriptionMetadata, 'WebPositionSettingsDescriptionMetadata');
    WebPositionSettingsDescriptionMetadata.a = null;
    return WebPositionSettingsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebPositionSettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSizeDescriptionMetadata } from "./WebSizeDescriptionMetadata";
import { WebPositionSettingsDescription } from "./WebPositionSettingsDescription";
/**
 * @hidden
 */
export let WebPositionSettingsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPositionSettingsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPositionSettingsDescriptionMetadata.a == null) {
                WebPositionSettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPositionSettingsDescriptionMetadata.c(WebPositionSettingsDescriptionMetadata.a);
            }
            if (a.k(WebPositionSettingsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPositionSettingsDescriptionMetadata.a);
            WebSizeDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PositionSettings");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("HorizontalDirection", "ExportedType:string:GridHorizontalAlignment");
            a.item("HorizontalDirection@names", "Left;Center;Right");
            a.item("VerticalDirection", "ExportedType:string:GridVerticalAlignment");
            a.item("VerticalDirection@names", "Top;Middle;Bottom");
            a.item("HorizontalStartPoint", "ExportedType:string:GridHorizontalAlignment");
            a.item("HorizontalStartPoint@names", "Left;Center;Right");
            a.item("VerticalStartPoint", "ExportedType:string:GridVerticalAlignment");
            a.item("VerticalStartPoint@names", "Top;Middle;Bottom");
            a.item("MinSize", "ExportedType:WebSize");
        }
        static d(a) {
            WebPositionSettingsDescriptionMetadata.b(a);
            a.ae("WebPositionSettings", () => new WebPositionSettingsDescription());
            a.ad("WebPositionSettings", WebPositionSettingsDescriptionMetadata.a);
        }
    }
    WebPositionSettingsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPositionSettingsDescriptionMetadata, 'WebPositionSettingsDescriptionMetadata');
    WebPositionSettingsDescriptionMetadata.a = null;
    return WebPositionSettingsDescriptionMetadata;
})();
